@@ -339,7 +339,7 @@ class IKafkaMessagingProxy(object):
                 request_body.response_required = True
                 response_required = True
 
-            request.header.timestamp = int(round(time.time() * 1000))
+            request.header.timestamp.GetCurrentTime()
             request_body.rpc = rpc
             for a, b in six.iteritems(kwargs):
                 arg = Argument()
@@ -372,8 +372,7 @@ class IKafkaMessagingProxy(object):
             response = InterContainerMessage()
             response_body = InterContainerResponseBody()
             response.header.id = msg_header.id
-            response.header.timestamp = int(
-                round(time.time() * 1000))
+            response.header.timestamp.GetCurrentTime()
             response.header.type = MessageType.Value("RESPONSE")
             response.header.from_topic = msg_header.to_topic
             response.header.to_topic = msg_header.from_topic
@@ -398,7 +397,7 @@ class IKafkaMessagingProxy(object):
                 log.debug("unsupported-msg", msg_type=type(message.body))
                 return None
             log.debug("parsed-response", type=message.header.type, from_topic=message.header.from_topic,
-                  to_topic=message.header.to_topic)
+                  to_topic=message.header.to_topic, transaction_id=message.header.id)
             return resp
         except Exception as e:
             log.exception("parsing-response-failed", msg=msg, e=e)
@@ -494,6 +493,7 @@ class IKafkaMessagingProxy(object):
                                   to_topic=res_topic)
             elif message.header.type == MessageType.Value("RESPONSE"):
                 trns_id = self._to_string(message.header.id)
+                log.debug('received-response', transaction_id=trns_id)
                 if trns_id in self.transaction_id_deferred_map:
                     resp = self._parse_response(val)
 
@@ -556,10 +556,10 @@ class IKafkaMessagingProxy(object):
                 self.transaction_id_deferred_map[
                     self._to_string(request.header.id)] = wait_for_result
             log.debug("message-send", transaction_id=transaction_id, to_topic=to_topic,
-                      from_topic=reply_topic)
+                      from_topic=reply_topic, rpc=rpc)
             yield self._send_kafka_message(to_topic, request)
             log.debug("message-sent", transaction_id=transaction_id, to_topic=to_topic,
-                      from_topic=reply_topic)
+                      from_topic=reply_topic, rpc=rpc)
 
             if response_required:
                 res = yield wait_for_result
@@ -569,7 +569,7 @@ class IKafkaMessagingProxy(object):
 
                 if res is not None:
                     if res.success:
-                        log.debug("send-message-response", rpc=rpc)
+                        log.debug("send-message-response", transaction_id=transaction_id, rpc=rpc)
                         if callback:
                             callback((res.success, res.result))
                         else:
@@ -577,7 +577,7 @@ class IKafkaMessagingProxy(object):
                     else:
                         # this is the case where the core API returns a grpc code.NotFound.  Return or callback
                         # so the caller can act appropriately (i.e add whatever was not found)
-                        log.warn("send-message-response-error-result", kafka_request=request, kafka_result=res)
+                        log.warn("send-message-response-error-result", transaction_id=transaction_id, rpc=rpc, kafka_request=request, kafka_result=res)
                         if callback:
                             callback((res.success, None))
                         else:
